Object subclass: #NmAbstractServer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Support-Server'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmAbstractServer class
	instanceVariableNames: 'default '!

!NmAbstractServer class methodsFor: 'class initialization' stamp: 'mu 3/24/2003 02:01'!
basicInitialize
	default _ nil.
	self registerServices.! !

!NmAbstractServer class methodsFor: 'class initialization' stamp: 'mu 3/12/2003 00:18'!
initialize
	self initializeAll! !

!NmAbstractServer class methodsFor: 'class initialization' stamp: 'mu 3/12/2003 00:19'!
initializeAll
	"NmAbstractServer initializeAll"
	self allSubclasses do:[:each | each initialize]! !


!NmAbstractServer class methodsFor: 'accessing' stamp: 'mu 3/13/2003 19:27'!
default
	default
		ifNil: [default _ self basicNew].
	^ default! !


!NmAbstractServer class methodsFor: 'utilities' stamp: 'mu 3/12/2003 00:23'!
inspectRegisteredServices
	"NmAbstractServer inspectRegisteredServices"
	SoapServiceHandler default serviceHome inspect! !


!NmAbstractServer class methodsFor: 'private' stamp: 'mu 3/12/2003 00:44'!
registerServiceNamed: serviceNameSymbol paramNames: anArrayOfParamNames
	| impl serv |
	impl := self default.
	serv := SoapService implementor: impl selector: serviceNameSymbol.
	serv signature: (SoapServiceSignature name: serviceNameSymbol asString paramNames: anArrayOfParamNames).
	serv targetObjectURI: (NmServerSettings adminServerUrl asUrl fullPath).
	SoapServiceHandler default add: serv.

	! !


!NmAbstractServer class methodsFor: 'instance creation' stamp: 'mu 3/13/2003 19:25'!
new
	self shouldNotImplement! !


Object subclass: #NmServerInitializer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Support-Server'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmServerInitializer class
	instanceVariableNames: ''!

!NmServerInitializer class methodsFor: 'class initialization' stamp: 'MU2 1/21/2003 18:08'!
initialize
	"NmServerInitializer initialize"
	Smalltalk addToStartUpList: self.
	! !

!NmServerInitializer class methodsFor: 'class initialization' stamp: 'MU2 1/21/2003 18:03'!
obsolete
	
	Smalltalk removeFromStartUpList: self.
	! !


!NmServerInitializer class methodsFor: 'system startup' stamp: 'mu 3/15/2003 02:06'!
startUp
	"NmServerInitializer startUp"
	NmFlapSetup addFlap.
	NmResolverServer initialize.
	NmServerManager startAdminServer.
	
	NmTranscript crShow: self name , ': initialize success'! !


NmAbstractSettings subclass: #NmServerSettings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Support-Server'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmServerSettings class
	instanceVariableNames: ''!

!NmServerSettings class methodsFor: 'accessing' stamp: 'mu 3/10/2003 18:12'!
adminServerPort
	^ self properties at: #adminServerPort ifAbsentPutValue: self defaultAdminServerPort! !

!NmServerSettings class methodsFor: 'accessing' stamp: 'mu 5/6/2003 01:35'!
adminServerPort: aValue 
	"NmServerSettings adminServerPort: 8080"
	| aNumber |
	[aNumber _ aValue asNumber]
		on: Error
		do: [^ false].
	self properties at: #adminServerPort put: aNumber.
	self changed: #adminServerPort.
	
	SoapServerSetup restartAt: #http port: aNumber! !


!NmServerSettings class methodsFor: 'constants' stamp: 'mu 3/10/2003 18:13'!
defaultAdminServerPort
	^ 80! !


!NmServerSettings class methodsFor: 'actions' stamp: 'mu 3/10/2003 18:34'!
toggleAdminServerRunning
	| isRunning |
	(isRunning _ self isAdminServerRunning)
		ifTrue: [NmServerManager stopAdminServer]
		ifFalse: [NmServerManager startAdminServer].
	^ isRunning not! !


!NmServerSettings class methodsFor: 'testing' stamp: 'mu 5/6/2003 01:40'!
isAdminServerRunning
	"NmServerSettings isAdminServerRunning"
	| descriptor |
	descriptor _ ('http:', self adminServerPort asString) asSymbol.
	^SoapServerSetup runningTransportDescriptions includes: descriptor! !


NmAbstractSettingsMorph subclass: #NmServerSettingsMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Support-Server'!

!NmServerSettingsMorph methodsFor: 'factory' stamp: 'ns 1/22/2003 17:23'!
settingClass
	^ self class settingClass! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmServerSettingsMorph class
	instanceVariableNames: ''!

!NmServerSettingsMorph class methodsFor: 'private' stamp: 'mu 3/10/2003 18:38'!
createWindow
	"NmServerSettingsMorph createWindow openInHand."
	| textField row checkBox window inst |
	window _ self createSystemWindow.
	(inst _ window findA: self)
		ifNil: [^ self error: 'System Window not found.'].
	row _ self buildRowLabeled: 'map server port (ADMIN only):'.
	textField _ self buildTextField: #adminServerPort.
	row addMorphBack: textField.
	checkBox _ UpdatingThreePhaseButtonMorph checkBox target: self settingClass;
				 actionSelector: #toggleAdminServerRunning;
				 getSelector: #isAdminServerRunning.
	row addMorphBack: checkBox.
	inst addMorphBack: row.

	row _ self buildRowLabeled: 'map path: '.
	textField _ self buildTextField: #mapPath.
	row addMorphBack: textField.
	inst addMorphBack: row.

	row _ self buildResetDefaultButtonRowOn: inst.
	inst addMorphBack: row.
	window extent: self windowExtent.
	^ window! !


!NmServerSettingsMorph class methodsFor: 'defaluts' stamp: 'ns 1/22/2003 17:19'!
labelString
	^ 'NetMorph Server setting'! !


!NmServerSettingsMorph class methodsFor: 'constants' stamp: 'mu 5/29/2003 12:55'!
windowExtent
	^ 410 @ 100! !


!NmServerSettingsMorph class methodsFor: 'factory' stamp: 'ns 1/22/2003 16:41'!
settingClass
	^ NmServerSettings! !


Object subclass: #NmServerUtil
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Support-Server'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmServerUtil class
	instanceVariableNames: ''!

!NmServerUtil class methodsFor: 'soap support' stamp: 'ns 1/23/2003 14:33'!
inspectRegisteredServices
	"NmServerUtil inspectRegisteredServices"
	SoapServiceHandler default serviceHome inspect! !

!NmServerUtil class methodsFor: 'soap support' stamp: 'mu 5/6/2003 01:39'!
runningTransportDescriptions
	"NmUtil runningTransportDescriptions"
	"Show what transport server(s) is running"
	| setup |
	(setup _ self soapServerSetup)
		ifNil: [^ #()].
	^setup runningTransportDescriptions! !

NmAbstractServer initialize!
NmServerInitializer initialize!